@@ -69,7 +69,7 @@ int RemoteDesktopsModel::rowCount(const QModelIndex &) const
 Qt::ItemFlags RemoteDesktopsModel::flags(const QModelIndex &index) const
 {
     if (!index.isValid())
-        return 0;
+        return nullptr;
     if (index.column() == RemoteDesktopsModel::Favorite) {
         return Qt::ItemIsEnabled | Qt::ItemIsUserCheckable;
     }
@@ -127,6 +127,7 @@ QVariant RemoteDesktopsModel::data(const QModelIndex &index, int role) const
             case RemoteDesktop::None:
                 return i18nc("Where each displayed link comes from", "None");
             }
+            // fall-through
         default:
             return QVariant();
         }
